@@ -4,11 +4,19 @@
 # The following block is used by usethis to automatically manage
 # roxygen namespace tags. Modify with care!
 ## usethis namespace: start
-#' @useDynLib PROJ, PROJ_proj_trans_generic
-#' @useDynLib PROJ, PROJ_set_data_dir
+#' @useDynLib PROJ, .registration = TRUE
 ## usethis namespace: end
 NULL
 
+#' @noRd
+#' @importFrom libproj libproj_version
+.libproj_version <- function() {
+  ## purely to pass check
+  libproj::libproj_version()
+}
+NULL
+
+
 #' Generic Coordinate System Transformations Using 'PROJ'
 #'
 #' The goal of PROJ is to provide generic coordinate system transformations in R
@@ -17,7 +25,7 @@ NULL
 #' \tabular{ll}{
 #'   \code{\link{ok_proj6}} determine if PROJ version >=6 is available
 #'   \code{\link{proj_trans_generic}} a light wrapper around the underlying transformation functionality of PROJ version 6 (or higher)
-#'   \code{\link{proj_create}} convert projection strings to WKT2 or PROJ format
+#'  removed   proj_create convert projection strings to WKT2 or PROJ format
 #'  }
 #' @name PROJ-package
 #' @docType package
