@@ -18,34 +18,17 @@
 #' ok_proj6()
 ok_proj6 <- function() {
 
-  test<- .C("PROJ_proj_trans_generic",
-            src_ = as.character("+proj=longlat +datum=WGS84"),
-            tgt_ = as.character("+proj=laea"),
-            n = as.integer(1L),
-            x_ = as.double(0), y_ = as.double(0), z_ = as.double(0), t_ = as.double(0),
-            success = as.integer(0),
-            NAOK=TRUE, PACKAGE = "PROJ")
-  if (!test[["success"]] == 1L) {
-    out <- FALSE
-  } else {
-    out <- TRUE
-    ## sanity check - see issue #14
-    new_syntax <- try(
-
-      .Call("PROJ_proj_create",
-            crs_ = as.character("EPSG:4326"),
-            format = as.integer(1L),
-            PACKAGE = "PROJ")
-    )
-    if (inherits(new_syntax, "try-error")) {
-      out <- FALSE
-    }
-  }
-
   mock_no_proj6 <- getOption("reproj.mock.noproj6")
-  if (out && !is.null(mock_no_proj6) && isTRUE(mock_no_proj6)) {
+
+  if (!is.null(mock_no_proj6) && isTRUE(mock_no_proj6)) {
     message("PROJ6 *is* available, but operating in mock-no-proj6 mode '?PROJ::ok_proj6'")
     out <- FALSE
+  } else {
+    test <- try(proj_trans(list(x = 0, y = 0),
+                           source = "+proj=longlat +datum=WGS84",
+                           target = "+proj=laea"), silent = TRUE)
+    out <-   !inherits(test, "try-error")
   }
+
   out
 }
